networkx: Python package for complex networks
=============================================

Description
-----------

NetworkX (NX) is a Python package for the creation, manipulation, and
study of the structure, dynamics, and functions of complex networks.

License
-------

BSD


Upstream Contact
----------------

https://networkx.github.io/
